==> sigaddons-7.0.21.12.14.tar.gz: sigaddons-7.0.21.12.14/sigaddons/crm_br_profiling/__openerp__.py <==
# -*- encoding: utf-8 -*-
##############################################################################
#
#    OpenERP, Open Source Management Solution
#    Copyright (C) 2004-2009 Tiny SPRL (<http://tiny.be>). All Rights Reserved
#    $Id$
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
##############################################################################


{
    'name': 'crm_br_profiling management',
    'version': '7.0.21.12.14',
    'category': 'CRM',
    'description': """
    This module allows users to perform segmentation within pessoas.
    It uses the profiles criteria from the earlier segmentation module and improve it. Thanks to the new concept of questionnaire. You can now regroup questions into a questionnaire and directly use it on a pessoa.

    It also has been merged with the earlier crm_br & SRM segmentation tool because they were overlapping.

    The menu items related are in "crm_br & SRM\Configuration\Segmentations"


    * Note: this module is not compatible with the module segmentation, since it's the same which has been renamed.
    """,
    'author': 'Tiny',
    'website': 'http://www.openerp.com',
    'depends': ['crm_br'],
    'data': ['security/ir.model.access.csv',
                   'views/crm_br_profiling_wizard.xml',
                   'views/questionnaire_view.xml',
                   'views/view_answer_view.xml',
                   'views/view_question_view.xml',
                   'inherit/pessoa_view.xml',
                   'inherit/crm_br_case_form_view.xml',
                   'views/crm_br.crm_br_segmentation_view.xml',
                   'views/pessoa_crm_br_segmentation_view.xml',
                   'views/action.xml',
                   'views/menu.xml',
                  ],
    'installable': True,
    "application": True,
    'active': False,
}
# vim:expandtab:smartindent:tabstop=4:softtabstop=4:shiftwidth=4:

==> sigaddons-7.0.2310.2.tar.gz: sigaddons-7.0.2310.2/sigaddons/crm_br_profiling/__openerp__.py <==
# -*- encoding: utf-8 -*-
##############################################################################
#
#    OpenERP, Open Source Management Solution
#    Copyright (C) 2004-2009 Tiny SPRL (<http://tiny.be>). All Rights Reserved
#    $Id$
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
##############################################################################


{
    'name': 'crm_br_profiling management',
    'version': '7.0.2310.2',
    'category': 'CRM',
    'description': """
    This module allows users to perform segmentation within pessoas.
    It uses the profiles criteria from the earlier segmentation module and improve it. Thanks to the new concept of questionnaire. You can now regroup questions into a questionnaire and directly use it on a pessoa.

    It also has been merged with the earlier crm_br & SRM segmentation tool because they were overlapping.

    The menu items related are in "crm_br & SRM\Configuration\Segmentations"


    * Note: this module is not compatible with the module segmentation, since it's the same which has been renamed.
    """,
    'author': 'Tiny',
    'website': 'http://www.openerp.com',
    'depends': ['crm_br'],
    'data': ['security/ir.model.access.csv',
                   'views/crm_br_profiling_wizard.xml',
                   'views/questionnaire_view.xml',
                   'views/view_answer_view.xml',
                   'views/view_question_view.xml',
                   'inherit/pessoa_view.xml',
                   'inherit/crm_br_case_form_view.xml',
                   'views/crm_br.crm_br_segmentation_view.xml',
                   'views/pessoa_crm_br_segmentation_view.xml',
                   'views/action.xml',
                   'views/menu.xml',
                  ],
    'installable': True,
    "application": True,
    'active': False,
}
# vim:expandtab:smartindent:tabstop=4:softtabstop=4:shiftwidth=4:
